using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;

using Microsoft.Devices.Sensors;

namespace Level
{
    /// <summary>
    /// This is the main type for your game
    /// </summary>
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;

        // Game World
        Texture2D bubbleTexture;
        Rectangle bubbleRectangle;
        Color bubbleColor = new Color(255,255,255,200);

        Texture2D dotTexture;
        Rectangle dotRectangle;

        float bubbleX;
        float bubbleY;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";

            // Frame rate is 30 fps by default for Windows Phone.
            TargetElapsedTime = TimeSpan.FromTicks(333333);

            graphics.PreferredBackBufferWidth = 480;
            graphics.PreferredBackBufferHeight = 800;
            graphics.SupportedOrientations = DisplayOrientation.Portrait;

            graphics.IsFullScreen = true;

        }

        /// <summary>
        /// Allows the game to perform any initialization it needs to before starting to run.
        /// This is where it can query for any required services and load any non-graphic
        /// related content.  Calling base.Initialize will enumerate through any components
        /// and initialize them as well.
        /// </summary>
        protected override void Initialize()
        {
            Accelerometer acc = new Accelerometer();

            acc.ReadingChanged += new EventHandler<AccelerometerReadingEventArgs>(acc_ReadingChanged);

            acc.Start();

            base.Initialize();
        }

        Vector3 accVector = Vector3.Zero;

        void acc_ReadingChanged(object sender, AccelerometerReadingEventArgs e)
        {
            accVector.X = (float)e.X;
            accVector.Y = (float)e.Y;
            accVector.Z = (float)e.Z;
        }

        /// <summary>
        /// LoadContent will be called once per game and is the place to load
        /// all of your content.
        /// </summary>
        protected override void LoadContent()
        {
            // Create a new SpriteBatch, which can be used to draw textures.
            spriteBatch = new SpriteBatch(GraphicsDevice);

            bubbleTexture = Content.Load<Texture2D>("Bubble");
            dotTexture = Content.Load<Texture2D>("Dot");

            dotRectangle = new Rectangle(
                0, 0,
                GraphicsDevice.Viewport.Width / 5,
                GraphicsDevice.Viewport.Width / 5);

            bubbleRectangle = new Rectangle(
                0, 0,
                GraphicsDevice.Viewport.Width / 5,
                GraphicsDevice.Viewport.Width / 5);

            bubbleX = (GraphicsDevice.Viewport.Width - bubbleRectangle.Width) / 2.0f;
            bubbleY = (GraphicsDevice.Viewport.Height - bubbleRectangle.Height) / 2.0f;

            dotRectangle.X = (int)((GraphicsDevice.Viewport.Width - dotRectangle.Width) / 2.0f);
            dotRectangle.Y = (int)((GraphicsDevice.Viewport.Height - dotRectangle.Height) / 2.0f);
        }

        /// <summary>
        /// UnloadContent will be called once per game and is the place to unload
        /// all content.
        /// </summary>
        protected override void UnloadContent()
        {
            // TODO: Unload any non ContentManager content here
        }

        /// <summary>
        /// Allows the game to run logic such as updating the world,
        /// checking for collisions, gathering input, and playing audio.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Update(GameTime gameTime)
        {
            // Allows the game to exit
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();

            float accBubbleX = bubbleX - (accVector.X * 200);
            float accBubbleY = bubbleY + (accVector.Y * 200);

            bubbleRectangle.X = (int)(accBubbleX + 0.5f);
            bubbleRectangle.Y = (int)(accBubbleY + 0.5f);

            base.Update(gameTime);
        }

        /// <summary>
        /// This is called when the game should draw itself.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.White);

            spriteBatch.Begin();

            spriteBatch.Draw(dotTexture, dotRectangle, Color.White);
            spriteBatch.Draw(bubbleTexture, bubbleRectangle, bubbleColor);

            spriteBatch.End();

            base.Draw(gameTime);
        }
    }
}
